@@ -1,5 +1,5 @@
 package Beam::Minion;
-our $VERSION = '0.010';
+our $VERSION = '0.011';
 # ABSTRACT: A distributed task runner for Beam::Wire containers
 
 #pod =head1 SYNOPSIS
@@ -139,7 +139,7 @@ Beam::Minion - A distributed task runner for Beam::Wire containers
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -258,6 +258,12 @@ L<Beam::Wire>, L<Beam::Runner>, L<Minion>
 
 Doug Bell <preaction@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Mohammad S Anwar
+
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2017 by Doug Bell.
